@@ -1,3 +1,4 @@
+#include <dlfcn.h>
 #include <Python.h>
 
 #include <mbarcode-qt/plugininterfaces.h>
@@ -44,6 +45,8 @@ void PythonQTWrapperPlugin::initInterface(QWidget *parent) {
     if (list.size()>0){
         cout << "Python plugins found, about to initialise Python runtime." << endl;
         this->initialised=true;
+        // Load the dynamic loader for python in case the python plugins require it
+        dlopen("libpython2.5.so.1", RTLD_LAZY | RTLD_GLOBAL); // should we search for the appropriate library here?
         Py_Initialize();
 
         Shiboken::init();
@@ -161,7 +164,7 @@ void PythonQTWrapperPlugin::initInterface(QWidget *parent) {
             PythonQTWrapperSink *s = new PythonQTWrapperSink(this, sinkInstance); //obj, widg
             sinks.append(s);
             // I guess we'll need to do this for each sink too.
-            connect(parent, SIGNAL(barcodeAnalysedSignal(QString,QString)), s, SLOT(barcodeAnalysed(QString,QString)));
+            QObject::connect(parent, SIGNAL(barcodeAnalysedSignal(QString,QString)), s, SLOT(barcodeAnalysed(QString,QString)));
 
         }
         //pythonInstances.append(instance);
@@ -189,6 +192,10 @@ void PythonQTWrapperPlugin::initInterface(QWidget *parent) {
     cout << "PythonQTWrapperPlugin::initInterface() successfully parsed " << QString("%1").arg(sinks.size()).toStdString() << " plugins." << endl;
     Py_DECREF(dict);
 
+    checkTimer = new QTimer(this);
+    connect(checkTimer, SIGNAL(timeout()),this,SLOT(checkPlugins()));
+
+
 }
 
 
@@ -222,4 +229,29 @@ QString PythonQTWrapperPlugin::getName()
 //    return new SettingsWindow(parent, this);
 //}
 
+void PythonQTWrapperPlugin::checkPlugins()
+{
+
+    foreach (PythonQTWrapperSink *s, sinks)
+    {
+        if(!s->getEnabled())
+            continue;
+
+        if( !addedPlugins.contains(s))
+        {
+            s->checkIfReady();
+            addedPlugins.append(s);
+            //emit isReady(); // this is done in the checkIfReady() fn
+        }
+    }
+
+    PluginUpdateCounter++;
+    if(PluginUpdateCounter > PLUGIN_COUNT_LIMIT)
+    {
+        checkTimer->stop();
+        PluginUpdateCounter=0;
+        addedPlugins.clear();
+    }
+}
+
 Q_EXPORT_PLUGIN2(mbqt_pythonqtwrapperplugin, PythonQTWrapperPlugin)
