@@ -11,6 +11,8 @@
 #include <QObject>
 #include <QStringList>
 
+#define PLUGIN_COUNT_LIMIT 6
+
 class PluginAction;
 class MainWindow;
 class PythonQTWrapperSink;
@@ -28,14 +30,22 @@ public:
     //QMainWindow* getSettingsWindow(QWidget *parent);
     QString getName();
 
+    QTimer *checkTimer;
 private:
     MaemoBarcodeWindow *parent;
     bool initialised;
 
+    int PluginUpdateCounter;
+    QList<PluginAction*> addedPlugins;
+
     // this is a list of the sinks provided by all the ini files
     QList<PythonQTWrapperSink *> sinks;
     //PyObject *_compiledClass;
     //QList<PyObject *> pythonInstances;
+
+private slots:
+    void checkPlugins();
+
 };
 
 #endif // PYTHONQTWRAPPERPLUGIN_H
