@@ -4,14 +4,20 @@
 #include <mbarcode-qt/pluginaction.h>
 #include "pythonqtwrapperplugin.h"
 #include "pythonqtwrappersink.h"
+//#include "QtCore/pyside_qtcore_python.h"
 
 #include <QtDBus>
 
 PythonQTWrapperSink::PythonQTWrapperSink(const PluginInterface *interface, PyObject* sinkInstance/*, QObject *obj, QWidget *widg*/) : PluginAction(interface)
 {
     this->sinkInstance=sinkInstance;
+    this->plugin = static_cast<PythonQTWrapperPlugin *>(const_cast<PluginInterface *>(interface)); // we need this so we can start and stop the timer
+
 //    this->obj = obj;
 //    this->widg = widg;
+
+    //QObject* me = Shiboken::Converter<QObject*>::toCpp(sinkInstance);
+    //QObject::connect(me, SIGNAL(isReady()), this, SLOT(getIsReadySignal()));
 }
 
 QString PythonQTWrapperSink::getName() // this does not change, so we save the name and can then return it with less overhead
@@ -102,35 +108,64 @@ QString PythonQTWrapperSink::getInformativeText() {
     return mytext;
 }
 
-bool PythonQTWrapperSink::isReady()
+void PythonQTWrapperSink::checkIfReady()
 {
-    bool ready = false;
-    char method_name[] = "isReady";
+        bool ready = false;
+        char method_name[] = "isReady";
 
-    //qDebug() << "PythonQTWrapperSink just called isReady()";
+        //qDebug() << "PythonQTWrapperSink just called isReady()";
 
-    // get class method
-    PyObject *output = PyObject_CallMethod(this->sinkInstance, method_name, NULL);
+        // get class method
+        PyObject *output = PyObject_CallMethod(this->sinkInstance, method_name, NULL);
+
+        if (output != NULL){
+            ready = (bool)PyInt_AsLong(output); // output will be -1 if an error occurred, but that works for us
+            //qDebug() << "PythonQTWrapperSink::isReady() returning " << ready;
+            if ( PyErr_Occurred() )
+                PyErr_Print();
+        }else{
+            if ( PyErr_Occurred() )
+                PyErr_Print();
+        }
+        Py_DECREF(output);
+
+        if(ready)
+            emit isReady();
 
-    if (output != NULL){
-        ready = (bool)PyInt_AsLong(output); // output will be -1 if an error occurred, but that works for us
-        //qDebug() << "PythonQTWrapperSink::isReady() returning " << ready;
-        if ( PyErr_Occurred() )
-            PyErr_Print();
-    }else{
-        if ( PyErr_Occurred() )
-            PyErr_Print();
-    }
-    Py_DECREF(output);
-    return ready;
 }
 
+//bool PythonQTWrapperSink::isReady()
+//    bool ready = false;
+//    char method_name[] = "isReady";
+
+//    //qDebug() << "PythonQTWrapperSink just called isReady()";
+
+//    // get class method
+//    PyObject *output = PyObject_CallMethod(this->sinkInstance, method_name, NULL);
+
+//    if (output != NULL){
+//        ready = (bool)PyInt_AsLong(output); // output will be -1 if an error occurred, but that works for us
+//        //qDebug() << "PythonQTWrapperSink::isReady() returning " << ready;
+//        if ( PyErr_Occurred() )
+//            PyErr_Print();
+//    }else{
+//        if ( PyErr_Occurred() )
+//            PyErr_Print();
+//    }
+//    Py_DECREF(output);
+//    return ready;
+//}
+
 void PythonQTWrapperSink::clickAction(QWidget *parentWindow)
 {
     // call the plugin's main Python method here
     char method_name[] = "clickAction";
     PyObject_CallMethod(this->sinkInstance, method_name, NULL);
     qDebug() << "PythonQTWrapperSink just called clickAction()";
+
+    // we've been called, so no need to keep looking for plugins to fill the list
+    if(this->plugin->checkTimer->isActive())
+        this->plugin->checkTimer->stop();
 }
 
 void PythonQTWrapperSink::barcodeAnalysed(QString barcodeType, QString barcodeData) {
@@ -145,4 +180,10 @@ void PythonQTWrapperSink::barcodeAnalysed(QString barcodeType, QString barcodeDa
     PyObject_CallMethod(this->sinkInstance, method_name, format, barcodeType.toUtf8().constData(), barcodeData.toUtf8().constData()); // unicode, unicode - check this is ok
     qDebug() << "PythonQT Wrapper plugin just called barcodeAnalysed()";
 
+    //emit isReady();
+
+    // make sure the list filling timer is up and running
+    if(!this->plugin->checkTimer->isActive())
+        this->plugin->checkTimer->start(500); // we should probably allow this to be set somewhere
+
 }
