@@ -9,7 +9,7 @@
 
 class PythonQTWrapperPlugin;
 
-class PythonQTWrapperSink : public QObject, public PluginAction
+class PythonQTWrapperSink : public PluginAction //public QObject, // removed as otherwise we get direct base inaccessible due to ambiguity, etc
 {
     Q_OBJECT
 public:
@@ -18,8 +18,14 @@ public:
     QString getText();
     QImage getImage();
     QString getInformativeText();
-    bool isReady();
+    //bool isReady();
     void clickAction(QWidget *parentWindow);
+
+    void checkIfReady();
+
+signals:
+    void isReady();
+
 private:
     QString sinkBarcodeType;
     QString sinkBarcodeData;
@@ -29,8 +35,11 @@ private:
     //QObject* obj;
     //QWidget *widg;
 
+    PythonQTWrapperPlugin *plugin;
+
 private slots:
     void barcodeAnalysed(QString barcodeType, QString barcodeData);
+
 };
 
 #endif // PYTHONQTWRAPPERSINK_H
